<?php

namespace wcf\acp\page;

use wcf\data\menu\item\MenuItemNodeTree;
use wcf\data\menu\Menu;
use wcf\page\AbstractPage;
use wcf\system\exception\IllegalLinkException;
use wcf\system\WCF;

/**
 * Shows a list of menu items.
 *
 * @author  Marcel Werk
 * @copyright   2001-2019 WoltLab GmbH
 * @license GNU Lesser General Public License <http://opensource.org/licenses/lgpl-license.php>
 * @since   3.0
 */
class MenuItemListPage extends AbstractPage
{
    /**
     * @inheritDoc
     */
    public $activeMenuItem = 'wcf.acp.menu.link.cms.menu.list';

    /**
     * @inheritDoc
     */
    public $neededPermissions = ['admin.content.cms.canManageMenu'];

    /**
     * menu item node tree
     * @var MenuItemNodeTree
     */
    public $menuItems;

    /**
     * menu id
     * @var int
     */
    public $menuID = 0;

    /**
     * menu object
     * @var Menu
     */
    public $menu;

    /**
     * @inheritDoc
     */
    public function readParameters()
    {
        parent::readParameters();

        if (isset($_REQUEST['id'])) {
            $this->menuID = \intval($_REQUEST['id']);
        }
        $this->menu = new Menu($this->menuID);
        if (!$this->menu->menuID) {
            throw new IllegalLinkException();
        }
    }

    /**
     * @inheritDoc
     */
    public function readData()
    {
        parent::readData();

        $this->menuItems = new MenuItemNodeTree($this->menuID, null, false);
    }

    /**
     * @inheritDoc
     */
    public function assignVariables()
    {
        parent::assignVariables();

        WCF::getTPL()->assign([
            'menuID' => $this->menuID,
            'menu' => $this->menu,
            'menuItemNodeList' => $this->menuItems->getNodeList(),
        ]);
    }
}
